==> OpenMx_2.3.1.tar.gz: OpenMx/demo/BivariateSaturated_MatrixRawCholesky.R <==
#
#   Copyright 2007-2015 The OpenMx Project
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
# 
#        http://www.apache.org/licenses/LICENSE-2.0
# 
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


# -----------------------------------------------------------------------------
# Program: BivariateSaturated_MatrixRawCholesky.R  
# Author: Hermine Maes
# Date: 2009.08.01 
#
# ModelType: Saturated
# DataType: Continuous
# Field: None
#
# Purpose: 
#      Bivariate Saturated model to estimate means and (co)variances 
#      using Cholesky Decomposition
#      Matrix style model input - Raw data input
#
# RevisionHistory:
#      Hermine Maes -- 2009.10.08 updated & reformatted
#      Ross Gore -- 2011.06.15 added Model, Data & Field metadata     
# -----------------------------------------------------------------------------

require(OpenMx)
require(MASS)
# Load Libraries
# -----------------------------------------------------------------------------

set.seed(200)
rs=.5
xy <- mvrnorm (1000, c(0,0), matrix(c(1,rs,rs,1),2,2))
testData <- xy
testData <- testData[, order(apply(testData, 2, var))[2:1]] #put the data columns in order from largest to smallest variance
# Note: Users do NOT have to re-order their data columns.  This is only to make data generation the same on different operating systems: to fix an inconsistency with the mvrnorm function in the MASS package.
selVars <- c("X","Y")
dimnames(testData) <- list(NULL, selVars)
summary(testData)
cov(testData)
# Simulate Data
# -----------------------------------------------------------------------------

bivSatModel6 <- mxModel("bivSat6",
    mxMatrix(
		type="Full", 
		nrow=2, 
		ncol=2, 
		free=c(TRUE,TRUE,FALSE,TRUE), 
		values=c(1,.2,0,1), 
		name="Chol"
	),
	mxMatrix(
		type="Full", 
		nrow=1, 
		ncol=2, 
		free=TRUE, 
		values=c(0,0), 
		name="expMean"
	),
    mxAlgebra(
		expression=Chol %*% t(Chol), 
		name="expCov"
	),
	mxData(
		observed=testData, 
		type="raw"
	),
	mxFitFunctionML(),mxExpectationNormal(
		covariance="expCov",
		means="expMean",
		dimnames=selVars
	)
)

bivSatFit6 <- mxRun(bivSatModel6)
EM <- mxEval(expMean, bivSatFit6)
EC <- mxEval(expCov, bivSatFit6)
LL <- mxEval(objective,bivSatFit6)
# example 6: Saturated Model with Raw Data and Matrix-Style Input
# -----------------------------------------------------------------------------

Mx.EM <- matrix(c(0.03211188, -0.004889211),1,2)
Mx.EC <- matrix(c(1.0092891, 0.4813504, 0.4813504, 0.9935366),2,2)
Mx.LL <- 5415.772
# Mx answers hard-coded
# -------------------------------------
# example Mx..2: Saturated Model with Raw Data
# -----------------------------------------------------------------------------

omxCheckCloseEnough(LL,Mx.LL,.001)
omxCheckCloseEnough(EC,Mx.EC,.001)
omxCheckCloseEnough(EM,Mx.EM,.001)
# 6: RawMat Cholesky
# -------------------------------------
# Compare OpenMx results to Mx results 
# (LL: likelihood; EC: expected covariance, EM: expected means)
# -----------------------------------------------------------------------------

==> OpenMx_2.6.9.tar.gz: OpenMx/demo/BivariateSaturated_MatrixRawCholesky.R <==
#
#   Copyright 2007-2016 The OpenMx Project
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
# 
#        http://www.apache.org/licenses/LICENSE-2.0
# 
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


# -----------------------------------------------------------------------------
# Program: BivariateSaturated_MatrixRawCholesky.R  
# Author: Hermine Maes
# Date: 2009.08.01 
#
# ModelType: Saturated
# DataType: Continuous
# Field: None
#
# Purpose: 
#      Bivariate Saturated model to estimate means and (co)variances 
#      using Cholesky Decomposition
#      Matrix style model input - Raw data input
#
# RevisionHistory:
#      Hermine Maes -- 2009.10.08 updated & reformatted
#      Ross Gore -- 2011.06.15 added Model, Data & Field metadata     
# -----------------------------------------------------------------------------

require(OpenMx)
require(MASS)
# Load Libraries
# -----------------------------------------------------------------------------

set.seed(200)
rs=.5
xy <- mvtnorm::rmvnorm (1000, c(0,0), matrix(c(1,rs,rs,1),2,2))
testData <- xy
testData <- testData[, order(apply(testData, 2, var))[2:1]] #put the data columns in order from largest to smallest variance
# Note: Users do NOT have to re-order their data columns.  This is only to make data generation the same on different operating systems: to fix an inconsistency with the mvtnorm::rmvnorm function in the MASS package.
selVars <- c("X","Y")
dimnames(testData) <- list(NULL, selVars)
summary(testData)
cov(testData)
# Simulate Data
# -----------------------------------------------------------------------------

bivSatModel6 <- mxModel("bivSat6",
    mxMatrix(
		type="Full", 
		nrow=2, 
		ncol=2, 
		free=c(TRUE,TRUE,FALSE,TRUE), 
		values=c(1,.2,0,1), 
		name="Chol"
	),
	mxMatrix(
		type="Full", 
		nrow=1, 
		ncol=2, 
		free=TRUE, 
		values=c(0,0), 
		name="expMean"
	),
    mxAlgebra(
		expression=Chol %*% t(Chol), 
		name="expCov"
	),
	mxData(
		observed=testData, 
		type="raw"
	),
	mxFitFunctionML(),mxExpectationNormal(
		covariance="expCov",
		means="expMean",
		dimnames=selVars
	)
)

bivSatFit6 <- mxRun(bivSatModel6)
EM <- mxEval(expMean, bivSatFit6)
EC <- mxEval(expCov, bivSatFit6)
LL <- mxEval(objective,bivSatFit6)
# example 6: Saturated Model with Raw Data and Matrix-Style Input
# -----------------------------------------------------------------------------

omxCheckCloseEnough(LL,5407.037,.001)
omxCheckCloseEnough(c(EC),c(1.066, 0.475, 0.475, 0.929),.001)
omxCheckCloseEnough(c(EM),c(0.058, 0.006),.001)
# 6: RawMat Cholesky
# -------------------------------------
# Compare OpenMx results to Mx results 
# (LL: likelihood; EC: expected covariance, EM: expected means)
# -----------------------------------------------------------------------------
